/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.stock.offline;

import java.io.FileReader;
import java.util.List;
import nl.cloudfarming.client.model.CropProtection;
import nl.cloudfarming.client.model.CropProtectionMessage;
import nl.cloudfarming.client.model.crop.Crop;
import nl.cloudfarming.client.model.crop.CropService;
import org.openide.util.Lookup;

/**
 * Factory to create cropProtections when no web service is online or installed
 * @author Merijn Zengers
 */
public class OfflineCropProtectionFactory {

    private OfflineMarshaller marshaller = new OfflineMarshaller();
    private String xml = "<CropProtectionMessage><CropProtection><authorizationNumber>4285</authorizationNumber><agent><name>gro-stop poeder</name><activeSubstance><name>chloorprofam</name><percentage>0</percentage></activeSubstance></agent><crop><name>crop.genus.solanum_tuberosum</name></crop><applicationMethod>knolbehandeling door poederen</applicationMethod><safetyTerm>60</safetyTerm><entryDelay>0</entryDelay><harvestDelay>0</harvestDelay><deterioration><name>ongewenste spruitvorming</name></deterioration><environmentalIssues><openCultivation><riskAquaticLife/><riskPollinators/><riskFighters/><riskApplicant/><organicMatterPercentage lowerLimit=\"0.0\" upperLimit=\"1.5\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage><organicMatterPercentage lowerLimit=\"1.5\" upperLimit=\"3.0\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage><organicMatterPercentage lowerLimit=\"3.0\" upperLimit=\"6.0\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage><organicMatterPercentage lowerLimit=\"6.0\" upperLimit=\"12.0\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage><organicMatterPercentage lowerLimit=\"12.0\" upperLimit=\"100.0\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage></openCultivation><horticulture><roomTreatment/><otherTechniques/></horticulture></environmentalIssues></CropProtection><CropProtection><authorizationNumber>4301</authorizationNumber><agent><name>gro-stop rood</name><activeSubstance><name>chloorprofam</name><percentage>0</percentage></activeSubstance></agent><crop><name>crop.genus.solanum_tuberosum</name></crop><applicationMethod>knolbehandeling door poederen</applicationMethod><safetyTerm>60</safetyTerm><entryDelay>0</entryDelay><harvestDelay>0</harvestDelay><deterioration><name>ongewenste spruitvorming</name></deterioration><environmentalIssues><openCultivation><riskAquaticLife/><riskPollinators/><riskFighters/><riskApplicant/><organicMatterPercentage lowerLimit=\"0.0\" upperLimit=\"1.5\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage><organicMatterPercentage lowerLimit=\"1.5\" upperLimit=\"3.0\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage><organicMatterPercentage lowerLimit=\"3.0\" upperLimit=\"6.0\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage><organicMatterPercentage lowerLimit=\"6.0\" upperLimit=\"12.0\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage><organicMatterPercentage lowerLimit=\"12.0\" upperLimit=\"100.0\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage></openCultivation><horticulture><roomTreatment/><otherTechniques/></horticulture></environmentalIssues></CropProtection><CropProtection><authorizationNumber>4563</authorizationNumber><agent><name>gro-stop fog</name><activeSubstance><name>chloorprofam</name><percentage>0</percentage></activeSubstance></agent><crop><name>crop.genus.solanum_tuberosum</name></crop><applicationMethod>knolbehandeling door nevelen</applicationMethod><safetyTerm>0</safetyTerm><entryDelay>0</entryDelay><harvestDelay>0</harvestDelay><deterioration><name>ongewenste spruitvorming</name></deterioration><environmentalIssues><openCultivation><riskAquaticLife/><riskPollinators/><riskFighters/><riskApplicant/><organicMatterPercentage lowerLimit=\"0.0\" upperLimit=\"1.5\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage><organicMatterPercentage lowerLimit=\"1.5\" upperLimit=\"3.0\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage><organicMatterPercentage lowerLimit=\"3.0\" upperLimit=\"6.0\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage><organicMatterPercentage lowerLimit=\"6.0\" upperLimit=\"12.0\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage><organicMatterPercentage lowerLimit=\"12.0\" upperLimit=\"100.0\"><riskSoilLife/><riskSpringLeaching/><riskAutumnLeaching/></organicMatterPercentage></openCultivation><horticulture><roomTreatment/><otherTechniques/></horticulture></environmentalIssues></CropProtection></CropProtectionMessage>";
    private CropService cropService = Lookup.getDefault().lookup(CropService.class);
    
    
    public List<CropProtection> getOfflineCropProtections() {
        CropProtectionMessage message = marshaller.unMarshall(xml);
        for(CropProtection cp : message.getCropProtection()){
            Crop crop = cropService.findCrop(cp.getClmCrop().getName());
            cp.setCrop(crop);
        }
        
        return message.getCropProtection();
    }
}
